package com.polonium.webdriver;

import java.lang.reflect.Method;

import org.junit.After;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.runner.Description;

import com.polonium.core.PoloniumTest;
import com.polonium.core.PoloniumTestRunner;
import com.polonium.webdriver.annotations.TargetBrowser;

public class PoloniumWebdriverTestRunner extends PoloniumTestRunner{
	private static final String EXCEPTION_MESSAGE_PREFIX = "Running on: ";

	public PoloniumWebdriverTestRunner(Class<? extends PoloniumTest> testClass) {
		super(testClass);
		setTargetBrowsers(testClass);
	}

	@Override
	protected void runMethods(){
		invokeMethods(BeforeClass.class);
		
		for (Method test : tests) {
			int testIndex = tests.indexOf(test);
			Description testDescription = descriptionBuilder.getTestRootDescription(testIndex);

			if (isReadyToRun(test, testDescription)) {
				try {
					// begin test running
					notifier.setStarted(testDescription);
					invokeMethods(Before.class);

					// run test on target browsers
					invokeOnTargetBrowsers(test);
					notifier.setOK(testDescription);

				} catch (Exception e) {
					notifier.checkException(testDescription, e, EXCEPTION_MESSAGE_PREFIX + DriverFactory.CURRENT_BROWSER.name());
				} finally {
					invokeMethods(After.class);
				}
			}
		}
	}
	
	private void invokeOnTargetBrowsers(Method test) throws Exception{
		//for(Browser browser : DriverFactory.TARGET_BROWSERS){
			//DriverFactory.CURRENT_BROWSER = browser;
			test.invoke(testInstance);
		//}
	}
	
	private void setTargetBrowsers(Class<?> testClass) {
//		if(testClass.isAnnotationPresent(TargetBrowser.class)){
//			DriverFactory.TARGET_BROWSERS = testClass.getAnnotation(TargetBrowser.class).value();
//		}
		if(testClass.isAnnotationPresent(TargetBrowser.class)){
			DriverFactory.CURRENT_BROWSER = testClass.getAnnotation(TargetBrowser.class).value();
		}
		
	}

}
